Date: 07 12, 2001 12:27:08 PM

Viewing Concept Trees

The concept tree shows you which nodes were built for a specific pass in the analyzer sequence.

To view nodes created in a parse tree:

1. In the Ana Tab, right-click on a pass.

2. Select View > Concept Tree.

Note: To view concept trees, you must run the analyzer with the Generate Logs button on.

Tip: You can also view a concept tree by selecting the View Concept Tree button on the Debug Toolbar.

## See Also

Viewing Parse Trees

Viewing Intermediate Trees

Viewing Partial Trees

Viewing Parse Tree Matches

Viewing Final Trees